@@ -2,10 +2,9 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-import json
-
+import compas
 import compas.geometry
-from compas.base import Base
+from compas.data import Data
 from compas.datastructures import Mesh
 from compas.files.urdf import URDFElement
 from compas.files.urdf import URDFGenericElement
@@ -146,7 +145,7 @@ class Origin(Frame):
         self.point = self.point * factor
 
 
-class BaseShape(Base):
+class BaseShape(Data):
     """Base class for all 3D shapes.
 
     Attributes
@@ -171,19 +170,6 @@ class BaseShape(Base):
     def from_data(cls, data):
         raise NotImplementedError
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
 
 class Box(BaseShape):
     """3D shape primitive representing a box.
@@ -475,7 +461,7 @@ class MeshDescriptor(BaseShape):
         return md
 
 
-class Color(Base):
+class Color(Data):
     """Color represented in RGBA.
 
     Parameters
@@ -519,21 +505,8 @@ class Color(Base):
         color.data = data
         return color
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Texture(Base):
+class Texture(Data):
     """Texture description.
 
     Parameters
@@ -573,21 +546,8 @@ class Texture(Base):
     def from_data(cls, data):
         return cls(**data)
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Material(Base):
+class Material(Data):
     """Material description.
 
     Parameters
@@ -634,25 +594,6 @@ class Material(Base):
         self.color = Color.from_data(data['color'])
         self.texture = Texture.from_data(data['texture']) if data['texture'] else None
 
-    @classmethod
-    def from_data(cls, data):
-        material = cls()
-        material.data = data
-        return material
-
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def get_color(self):
         """Get the RGBA color array of the material.
 
@@ -685,7 +626,7 @@ TYPE_CLASS_ENUM = {
 }
 
 
-class Geometry(Base):
+class Geometry(Data):
     """Geometrical description of the shape of a link.
 
     Parameters
@@ -754,19 +695,6 @@ class Geometry(Base):
         geo.data = data
         return geo
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     @property
     def geo(self):
         """Get geometry associated to this shape.
